@@ -1,3 +1,4 @@
+# Copyright 2014 Software Freedom Conservancy
 # Copyright 2008-2011 WebDriver committers
 # Copyright 2008-2011 Google Inc.
 #
@@ -27,7 +28,7 @@ import zipfile
 try:
     from cStringIO import StringIO as BytesIO
     bytes = str
-    str = unicode
+    str = basestring
 except ImportError:
     from io import BytesIO
 
@@ -340,8 +341,8 @@ class FirefoxProfile(object):
                     manifest = f.read()
             else:
                 raise IOError('Add-on path is neither an XPI nor a directory: %s' % addon_path)
-        except (IOError, KeyError), e:
-            raise AddonFormatError, str(e), sys.exc_info()[2]
+        except (IOError, KeyError) as e:
+            raise AddonFormatError(str(e), sys.exc_info()[2])
 
         try:
             doc = minidom.parseString(manifest)
@@ -356,11 +357,11 @@ class FirefoxProfile(object):
                 entry = node.nodeName.replace(em, "")
                 if entry in details.keys():
                     details.update({entry: get_text(node)})
-        except Exception, e:
-            raise AddonFormatError, str(e), sys.exc_info()[2]
+        except Exception as e:
+            raise AddonFormatError(str(e), sys.exc_info()[2])
 
         # turn unpack into a true/false value
-        if isinstance(details['unpack'], basestring):
+        if isinstance(details['unpack'], str):
             details['unpack'] = details['unpack'].lower() == 'true'
 
         # If no ID is set, the add-on is invalid
